function build_achrom_avi_no_plot(sec,m,M,col,fps,compress,folder,name)

% BUILD_ACHROM_AVI_NO_PLOT generates both an *.avi file from 2d or 3d data.
% This function scales the values of the colormap so that "m" is black and "M" is white.
%
% SYNTAX: build_achrom_avi_no_plot(Y,m,M,num_column,fst,compress,folder,name);
%
%        Y = movie data (2d or 3d array)
%        m = value to be depicted as black
%        M = value to be depicted as white
%        num_columns = number of columns in each frame
%        fps = Temporal sampling frequency (frames per second)
%        compress = 0 (uncompressed avi) or 1 (motion JPEG avi)
%        folder = string with full path to the folder where the avi file will be stored 
%        name = string name of the *.avi file (extension is automatically appended).
%               note that the file will be [folder,name,'.avi'] so write
%               the folder accordingly (ending with / or \)
%


s=size(sec);

    % Prepare the new file.
    if compress ==1
       vidObj = VideoWriter([folder,name,'.avi'],'Motion JPEG AVI');
    else
       vidObj = VideoWriter([folder,name,'.avi'],'Uncompressed AVI');
    end
    vidObj.FrameRate=fps;
    open(vidObj);

if length(s)==2

   nf=s(2)/col;
   nr = s(1);
   nc = col;
   
   % m = min(min(sec));
   % M = max(max(sec));

    % P = moviein(nf);

    sec = ((sec-m)/(M-m));

    for i=1:nf
        im=sacafot(sec,nr,nc,i);
        %figure(fig);colormap gray;
        %imagesc(im,[m M]),axis('equal'),axis('off')
        %lala=getframe;
        %P(:,i)=lala;
        writeVideo(vidObj,im);
        
    end   
   
else
   
   nr = s(1);
   nc = col;
   nf = s(3); 

   % m = min(min(min(sec)));
   % M = max(max(max(sec)));

   % P = moviein(nf);

    sec = ((sec-m)/(M-m));

    for i=1:nf
        im=sec(:,:,i);
        %figure(fig);colormap gray;
        %imagesc(im,[m M]),axis('equal'),axis('off')
        %lala=getframe;
        %P(:,i)=lala;
        writeVideo(vidObj,im);
    end   
   
end

% Close the file.
    close(vidObj);
