function build_color_avi_no_plot(sec4d,fps,compress,folder,name)

% BUILD_COLOR_AVI generates an *.avi file from 4d (spatio-chromatic-temporal) array.
% The sequence of N true-color images of size m*n is an array of dimensions m*n*3*N.  
%
% SYNTAX: build_color_avi_no_plot(sec4d,fst,compress,folder,name);
%
%        sec4d = movie data (4d array). It requires input in [0,1] range!
%        fps = Temporal sampling frequency (frames per second)
%        compress = 0 (uncompressed avi) or 1 (motion JPEG avi)
%        folder = string with full path to the folder where the avi file will be stored 
%        name = string name of the *.avi file (extension is automatically appended).
%               note that the file will be [folder,name,'.avi'] so write
%               the folder accordingly (ending with / or \)
%

s = size(sec4d);
% [folder,name,'.avi']

    % Prepare the new file.
    if compress ==1
       vidObj = VideoWriter([folder,name,'.avi'],'Motion JPEG AVI');
    else
       vidObj = VideoWriter([folder,name,'.avi'],'Uncompressed AVI');
    end
    vidObj.FrameRate=fps;
    open(vidObj);

if length(s)==2 | length(s)==3 

   disp(' ') 
   disp('Sorry: this function does not accept 2d/3d data, use build_achrom_movie_avi instead!')
   
else
   
   nr = s(1);
   nc = s(2);
   nf = s(4); 

    for i=1:nf
        im=squeeze(sec4d(:,:,:,i));
        %figure(fig);
        %imagesc(im),axis('equal'),axis('off')
        %lala=getframe;
        % P(:,i)=lala;
        writeVideo(vidObj,im);
    end   
   
end

% Close the file.
    close(vidObj);
