function MTF = mtf_watson(f,lambda,d)

% MTF_WATSON computes the mean human optical Modulation Transfer Function 
% reported in A.B. Watson, A formula for the mean human optical MTF as a function 
% of pupil size. Journal of Vision (2013) 13(6):18, 111
%
% Syntax:
%
% MTF = mtf_watson(f,lambda,d)
%
%   f = (radial) spatial frquency in cpd, f = sqrt(fx.^2+fy.^2), with fx fy from spatio_temp_freq_domain
%   lambda = wavelength in nm
%   d = pupil diameter in mm
%

u1 = 21.95 - 5.512*d + 0.3922*d^2;
u0 = (d*pi*1e6)/(lambda*180);

fn = f/u0;

D = ((2/pi)*(acos(fn)-fn.*sqrt(1-fn))).*double(fn<1);

MTF = ((1+(f/u1).^2).^(-0.62)).*sqrt(D);





