% PRIMERO OBJETO, LUEGO MOVIMIENTO
% 
% En este script se generan secuencias de un objeto en movimiento de forma
% que en cada fotograma se identifica claramente el objeto y por tanto,
% podrian realizarse estimaciones del movimiento basadas en
% correspondencias entre las caracteristicas del objeto en instantes de
% tiempo diferentes.
%
% En este script se generan 5 peliculas de un mismo objeto moviendose
% en el espacio 3D tomadas desde diferentes puntos de vista
%
% El movimiento del objeto esta definido por las siguientes
% consideraciones:
%
% - Inicialmente el objeto tiene una cierta posicion y velocidad (lineal y angular)
%   
% - El objeto esta sometido a un campo de fuerzas (aceleraciones lineal y angular)
%
% - El movimiento del objeto esta confinado en una caja 3D de forma que
%   rebota en sus limites (con un cierto coeficiente de restitucion).
%
%   NOTA: la integracion de las ecuaciones del movimiento se realiza con una
%   frecuencia temporal 5 veces superior a la frecuencia temporal de adquisicion 
%   de la pelicula, y se usa un algoritmo Runge Kutta de orden 4.
%
% La pelicula esta determinada por las siguientes consideraciones
%
% - Cada secuencia se toma desde un punto de vista (azimut y elevacion)
%
% - El objeto esta iluminado por una fuente lejana situada en una cierta
%   direccion (azimut y elevacion). El objeto es lambertiano con reflectancia unidad.
%
% - Se toman N fotogramas con una cierta frecuencia de muestreo temporal
%
% - El plano imagen tiene unos ciertos limites
%
% - El plano imagen se muestrea con Nx pixels por dimension

% Condiciones iniciales

    % Posicion y velocidad
    
         pos_vel=[6 6 6 -6 -1.5 0];
    
    % Angulo y velocidad angular
    
         ang_vel_ang=[0 0 0 0 0.5 0];

% Aceleraciones (campos de fuerza). Dos casos concretos:

    % Atraccion por un punto
       fact_atrac=7;
       punto=[3 3 3];
       aceleracion_lineal=['-',num2str(fact_atrac),'*[x(1)-',num2str(punto(1)),' x(2)-',num2str(punto(2)),' x(3)-',num2str(punto(3)),']/(sqrt(sum([x(1)-',num2str(punto(1)),' x(2)-',num2str(punto(2)),' x(3)-',num2str(punto(3)),'].^2)))^3']

       aceleracion_angular='[0 0 0]'; 
       
    % Gravedad (en el eje z)
       gravedad=9.8;
       aceleracion_lineal='-[0 0 9.8]';
       aceleracion_angular='[0 0 0]'; 

% Paredes de confinamiento (limites xm xM, ym yM, zm zM) y coeficiente de
% restitucion (perdida de energia en los rebotes)

       limites=[-1 7 -1 7 -1 7];
       coef_restit=0.7;
        
% Puntos de vista (azimut y elevacion)

vistas=[0 30;15 30;30 30;45 30;45+15 30];

% Iluminacion (azimut y elevacion)

ilumin=[15 60];

% Frecuencia de muestreo temporal (Intervalo temporal entre fotogramas) y numero de fotogramas

fst=20; % 20 fotogramas por segundo
dt=1/fst; 
N=100;

% Limites del plano imagen y numero de pixels

limit_imagen=[-2 8 -2 8];
Nx=100;

% Figura donde se representa

fig=1;

for i=1:5

[Peli,Posic_veloc,acel_CM,T,Angul_velocang,acelang,R,ptos0X,ptos0Y,ptos0Z,p3dx,p3dy,p3dz,...
       se_ve,p2dx,p2dy]=pelirott(aceleracion_lineal,aceleracion_angular,pos_vel,ang_vel_ang,...
       0,dt,N,5,limites,1,coef_restit,vistas(i,:),ilumin,1,limit_imagen,1.5,1.5,1.5,0,0,0,4,Nx,0.95,fig,...
       'c:\',['lala',num2str(i)]);

[PEL,ESTT,ACET,TTTT,ESTR,ACER,RRR,ptos0X,ptos0Y,ptos0Z,p3dx,p3dy,p3dz,se_ve,p2dx,p2dy]=...
    cargapel(Nx,Nx,['c:\lala',num2str(i)],[1 N]);   
   
    eval(['peli',num2str(i),'=PEL;']);
   
end
