% SENOS_MOVILES
% 
% Este script genera una secuencia de un conjunto de sinusoides moviendose con
% velocidad v. Se muestra que:

%
%    * El espectro se inclina correspondientemente  [  cumpliendo  fx*vx+fy*vy+ft=0  ]
%    * Se deshace la ambiguedad en la velocidad (si las sinusoides tienen orient. 
%      diferente dando lugar a bordes con distintas orientaciones). 
%    * Si se incrementa mucho la velocidad, las componentes de alta
%      frecuencia se salen del dominio discreto (cambiando su velocidad!): Aliasing! 


% Frecuencias de las sinusoides:

fre=[0 3;1 2;10 3];
contrastes=[0.5 0.5 0.4];

% Velocidad

v=[0.45 0;0.9 0;1.2 0;1.5 0;1.8 0;2 0];
v=[0.45 0;0.9 0;1.5 0];

%v=[1.8 0]

% Parametros del dominio espacio-temporal:

fsx=40;    % Frecuencia de muestreo espacial (en cl/grad)
fst=20;    % Frecuencia de muestreo temporal (en Hz)

Nx=100;     % Numero de muestras por dimension espacial (filas y columnas)
Nt=100;     % Numero de muestras en la dimension temporal (fotogramas)

% Parametros de la sinusoide

Lm=128;    % Luminacia media
%C=0.5;      % Contraste
% f=[3 0];
% f=[3 4];   % Frecuencias espaciales (en c/grad)
% ft=3;      % Frecuencia temporal (en Hz)

% Dominio espacio-temp

[x,y,t,fx,fy,ft] = spatio_temp_freq_domain(Nx,Nx,Nt,fsx,fsx,fst);
 
% Sinusoides

for kk=1:length(v(:,1));
vv=v(kk,:);
    
for i=1:length(fre(:,1));
    f=fre(i,:);
    C=contrastes(i);
    if i==1,
       S=Lm*(1+C*sin(2*pi*(f(1)*x+f(2)*y-(f(1)*vv(1)+f(2)*vv(2))*t)));
    elseif i==2
       S=S+Lm*C*sin(2*pi*(f(1)*x+f(2)*y-(f(1)*vv(1)+f(2)*vv(2))*t));     
    else    
       S=S+Lm*C*sin(2*pi*(f(1)*x+f(2)*y-(f(1)*vv(1)+f(2)*vv(2))*t));    
    end
end

% Pelicula

folder = 'C:\disco_portable\mundo_irreal\rutinas\Software_Katedra\Vistalab\sample_data\';
name = ['pulucula',num2str(kk)];
MOV = build_achrom_movie_avi(S,min(S(:)),max(S(:)),Nx,kk,fst,1,folder,name);

implay(then2now(S/max(S(:)),Nx))

% Visualizacion de la peli
%
% figure(1),movie(P,1,fst)

% Transformada

tf=fft3(S-mean(S(:)),1);

% Visualizacion de la transformada

show_fft3( tf, fsx, fst, kk+100);
view([0 0]),axis square
set(kk+100,'color',[1 1 1])
axis([-12 12 -12 12 -10 10])

if kk==1
   S1 = S; 
elseif kk==2
   S2 = S; 
else
   S3 = S; 
end

%vertf3d(tf,fsx,fst,2);
%vertf3d_3d(abs(tf).^(1/2),fsx,fst,100)

pause
end